Introduction
=====================================

.. note::

    The documentation is currently in transition from ``doxygen`` to Sphinx.
    This change requires a lot of re-writing.
    The rewriting is good because we'll get stuff up to date.
    The down side is that it will take a while!

``fwdpp`` is a ``C++14`` template library for implementing forward-time simulations of population- and quantitative- genetic models.

Some of you may have landed here because you want to *run* simulations.
We encourange you to check out `fwdpy11 <https://fwdpy11.readthedocs.io>`_, which is developed using ``fwdpp``

Citation
+++++++++++++++++++++++++++++++++++++

If you use ``fwdpp`` in your research, or a package developed with it, then please cite the following paper:

.. code-block:: latex

    @Article{,
      author = 	 {K. R. Thornton},
      title = 	 {A C++ Template Library for Efficient Forward-Time Population Genetic Simulation of Large Populations},
      journal = 	 {Genetics},
      year = 	 {2014},
      OPTkey = 	 {},
      volume = 	 {198},
      OPTnumber = 	 {},
      pages = 	 {157-166},
      OPTmonth = 	 {},
      OPTnote = 	 {},
      annote = 	 {doi:/10.1534/genetics.114.165019}
    }

